<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mediabox?lang_cible=es
// ** ne pas modifier le fichier **

return [

	// M
	'mediabox_description' => 'Por defecto, todos los enlaces definidos sobre imágenes (con un atributo tipo que describa el mime/type de la imafen) así como los enlaces con la clase <code>.mediabox</code> son enriquecidos por la caja multimedia.
	
Es posible configurar cada enlace, caso por caso, con clases adicionales:

-* <code>boxIframe</code> permite abrir el enlace en una caja en un iframe ;

-* <code>boxWidth-350px</code> permite definir un ancho de 350px para la caja;

-* <code>boxHeight-90pc</code> perite definir un alto de 90% para la caja.

Un panel de configuración permite modificar tanto las especificaciones generales como el aspecto de la caja, a partir de un conjunto de opciones disponibles. 
	
Este plugin funciona en los esqueletos que incluyen la baliza <code>#INSERT_HEAD</code>',
	'mediabox_nom' => 'MediaBox',
	'mediabox_slogan' => 'Caja multimedia',
];
